import frameworkApi from '@/api/framework'
import storage from '@/utils/storage'
import lStorage from '@/utils/localStorage'

const KEY_MENU_SELECTED = 'menu_selected'
const KEY_PAGE_BRANDCRUMB = 'page_brandcrumb'

export default {
  namespaced: true,
    state: {
      userInfo: { username: 'admin' }, //null,
      userId: "", //用户id
      permissions: {
        "system:role:delete": true,
        "system:role:create": true,
        "system:role:query": true,
        "system:role:setOpts": true
      },
      dictionary: {
        dictionaryValue: 'common',
        dictionaryType: 'common',
        groupId: '0',
        projectId: '0',
      },
      sidebarSelected: '', // sidebar选中的选项
      breadcrumb: [],
    },
    getters: {
      userId: state => state.userId,
      userInfo: state => state.userInfo,
      permissions: state => state.permissions,
      dictionary: state => state.dictionary,
      sidebarSelected: state => state.sidebarSelected,
      breadcrumb: state => {
        if (!state.breadcrumb) {
          let arr = storage.get(KEY_PAGE_BRANDCRUMB)
          if (arr) {
            state.breadcrumb = arr
          }
        }
        return state.breadcrumb
      }
    },
    mutations: {
      setDictionary: (state, val) => {
        state.dictionary = val
      },
      setSidebarSelected: (state, val) => {
        state.sidebarSelected = val
        storage.set(KEY_MENU_SELECTED, val)
        lStorage.set('screen_data', {path: val, data: {}})
      },
    },
  actions: {
    loadUserInfo({state}) {
      console.log(state)
      return new Promise((resolve, reject) => {
        frameworkApi.loadUserInfo().then(resp => {
          console.log(resp)
          if (resp.Result == 'success' && resp.UserId) {
            state.userInfo = {userName: resp.Username, userId: resp.UserId}
            state.userId = resp.UserId
            storage.set('user_name', resp.Username)
            storage.set('user_id', resp.UserId)
            state.permissions = {}
            if (resp.Permissions) {
              resp.Permissions.forEach(p => (state.permissions[p] = true))
            }
            state.projects = []
            if (resp.Projects) {
              if (resp.Projects[0] && resp.Projects[0].ProjId) {
                state.projectId = resp.Projects[0].ProjId
                state.secret = resp.Projects[0].Secret ? resp.Projects[0].Secret : ""
              }
              resp.Projects.forEach(proj =>
                state.projects.push({
                  id: proj.ProjId,
                  name: proj.ProjLocalName,
                  pwd: proj.Secret ? proj.Secret : ""
                })
              )
            }
          } else {
            state.userInfo = null

          }
          resolve(resp)
        })
      })
    },
    setBreadcrumb: {
      root: true,
      handler({ state }, val) {
        state.breadcrumb = []
        state.breadcrumb = val
        storage.set(KEY_PAGE_BRANDCRUMB, val)
      }
    }
  }
}